#ifndef TIMEPIX_TOT_DISTRIBUTION_PROCESSOR_H
#define TIMEPIX_TOT_DISTRIBUTION_PROCESSOR_H 1

//LCIO
#include <lcio.h>

//MARLIN
#include "marlin/Processor.h"
#include "TimePixPixelMode.h"
#include "TimePixMapListener.h"

namespace AIDA{
  class IHistogram1D;
  class IHistogram2D;
}


namespace marlintpc
{

    class TrackFitterFactory;
//    class TrackFitterBase;

    /** Fill the TOT values of all pixels in a histogram
     *
     *  <h4>Input - Prerequisites</h4>
     *  \li A Collection of tracker data
     *
     *  <h4>Output</h4>
     *  \li Histograms of the TOT value distribution
     *
     *  @param InputTrackes Name of input Hits collection (default: TPCHits)
     *  @param HistogramMinValueTOT  Minimum value in TOT histogram (default: 0.)
     *  @param HistogramMaxValueTOT  Maximal value in TOT histogram (default: 1000.) 
     *
     *
     *  @author Simone Zimmermann, University of Bonn
     */
    class TimePixTOTDistributionProcessor : public marlin::Processor{
			      
    public:
    
	virtual Processor*  newProcessor() { return new TimePixTOTDistributionProcessor ; }

	TimePixTOTDistributionProcessor();
    
	~TimePixTOTDistributionProcessor();

	virtual void init();

	virtual void processRunHeader( EVENT::LCRunHeader* run ) ;

	virtual void processEvent( LCEvent * evt ) ; 
    
    protected:

     std::string _inputColName ;    ///< the name of the input collection
     
     AIDA::IHistogram1D * _distributionTOTHisto; ///< The histogram of the TOT values

     float  _histogramMinValueTOT; ///< Minimum value in TOT histogram
     float  _histogramMaxValueTOT; ///< Maximum value in TOT histogram

     tpcconddata::TimePixMap * _timePixMap;

    };

}

#endif // TOT_DISTRIBUTION_PROCESSOR_H
