#ifndef PHOTOELECTRICPULSEEXTRACTIONPROCESSOR_H
#define PHOTOELECTRICPULSEEXTRACTIONPROCESSOR_H 1

// Marlin
#include <marlin/Processor.h>

// Gear
#include <gearimpl/GlobalPadIndex.h>

// LCIO
#include <lcio.h>

// stl
#include <string>
#include <set>

namespace marlintpc {

/** PhotoelectricPulseExtractionProcessor: takes the input pulse collection, finds the ones which are most-likely to be photoelectric pulses and puts them into another collection
 *    @author J. Abernathy (UVic)<br>
 */
class PhotoelectricPulseExtractionProcessor : public marlin::Processor {

public:

	PhotoelectricPulseExtractionProcessor() ;

	virtual void init() ;

	virtual Processor*  newProcessor() { return new PhotoelectricPulseExtractionProcessor(); }

	virtual void processRunHeader( lcio::LCRunHeader* run );

	virtual void processEvent( lcio::LCEvent * evt );

	virtual void check( lcio::LCEvent * evt );

	virtual void end();

private:

	/** the name of the collection the input pulses will be stored under
	*/
	std::string _input_tracker_pulses_collection_name;

	/** the name of the output collection which will contain the photoelectric pulses
	 */
	std::string _output_photoelectric_tracker_pulses_collection_name;

	/** The width of the acceptance interval (in ns) which is centred on the mode of the arrival times
	 */
	float _arrival_time_width;

	/** determines whether the output of this processor will be stored in a file after program termination (false) or not (true - default)
	*/
	bool _output_is_transient;

	/** specifies the name of the collection which stores the results of the projection finding
	 */
	std::string _projected_photogeometry_file_name;

	/** the beginning (in ns) of the interval of the arrival time for photoelectric data
	 */
	float _photopulse_interval_start;

	/** the end (in ns) of the interval of the arrival time for photoelectric data
	 */
	float _photopulse_interval_end;

	/** the set of global pad indices which should contain photoelectric data
	 */
	std::set< gear::GlobalPadIndex > _global_pad_indices;

};

}

#endif // PHOTOELECTRICPULSEEXTRACTIONPROCESSOR_H
