#ifdef USE_LCCD

#ifndef COUNTSTOPRIMARYELECTRONSPROCESSOR_H
#define COUNTSTOPRIMARYELECTRONSPROCESSOR_H 1

// MarlinTPC
#include "TPCConditionsHandler.h"

// Marlin
#include <marlin/Processor.h>

// LCIO
#include "lcio.h"

// stl
#include <string>

namespace marlintpc {

/** CountsToPrimaryElectronsProcessor: converts FADC counts into primary electrons (assumes a linear gain needing no corrections)
 *    @author J. Abernathy (UVic)<br>
 */
class CountsToPrimaryElectronsProcessor : public marlin::Processor {

public:

	CountsToPrimaryElectronsProcessor() ;

	virtual void init() ;

	virtual Processor*  newProcessor() { return new CountsToPrimaryElectronsProcessor(); }

	virtual void processRunHeader( lcio::LCRunHeader *run );

	virtual void processEvent( lcio::LCEvent *evt );

	virtual void check( lcio::LCEvent *evt );

	virtual void end();

private:

	/** the name of the collection the input pulses will be stored under
	*/
	std::string _input_tracker_pulses_collection_name;

	/** the name of the collection the output pulses will be stored under
	*/
	std::string _output_tracker_pulses_collection_name;

	/** the name of the collection the TPC conditions are stored with
	*/
	std::string _tpc_conditions_collection_name;

	/** determines whether the output of this processor will be stored in a file after program termination (false) or not (true - default)
	*/
	bool _output_is_transient;

	// how many runs / events have been processed sofar
	int _number_of_runs;
	int _number_of_events;

	/** the handler for the TPC conditions
	*/
	TPCConditionsHandler *_tpc_conditions;
};

}

#endif // COUNTSTOPRIMARYELECTRONSPROCESSOR_H
#endif // USE_LCCD
