#ifndef STRAIGHTKALTRACK_H
#define STRAIGHTKALTRACK_H

#include "AttKalTrack.h"

#include <cmath>
#include <TMatrixD.h>

namespace marlintpc 
{

    	/** This is the straight track class, which inherits from AttKalTrack. 
         *  Kalman filter algorithm is implemented inside this class.
     	 *  
     	 *  @author Bo Li, Tsinghua University
     	 *  @author Keisuke Fujii, KEK
     	 */

class StraightKalTrack : public AttKalTrack
{
public:
	StraightKalTrack(const TPCParameters* tp);

  	StraightKalTrack(const StraightKalTrack& orig);

        /** Create a track by copying from original track
         */
  	AttKalTrack* create(const AttKalTrack * orig=0);

        /** Add a new site to track and update track parameters
         */
  	bool doAddAndFilter(ModuleRowHit hit);

        /** Search track starting from hit
         */
  	bool searchTrack(ModuleRowHit hit);

        /** Reset parameters and data of track
         */
  	void reset();

        /** Get state vector
         */
  	inline TMatrixD getStateVec (){return _sv;}

        /** Get track type: straight line
         */
  	inline int      getType     (){return 0;  }

	inline double   getSlope    (){return _sv[0][0];}

	inline double   getIntercept(){return _sv[1][0];}

        /** Get the Chi2 increment at one step
         */
  	inline double   getDeltaChi2(){return _deltaChi2;}

	void printStateVector();
private:
        /** Filtered state vector
         */
	TMatrixD _sv;

        /** Predicted state vector
         */
  	TMatrixD _sv1;

	/** Transfer matrix 
         */ 
  	TMatrixD _H;

        /** Transpose of H
         */
  	TMatrixD _H_t;

        /** Kalman gain matrix
         */
  	TMatrixD _K;

        /** Covariance
         */
  	TMatrixD _P;

        /** Estimated covariance
         */
  	TMatrixD _P1;

        /** measurment error matrix
         */
  	TMatrixD _R;

        /** A 2*2 unit matrix
         */
  	TMatrixD _M_unit;

        /** The current Chi2 increament
         */
  	double _deltaChi2;
};

}
#endif
