#ifndef PRIMARYCLOUDIONISATIONPROCESSOR_H
#define PRIMARYCLOUDIONISATIONPROCESSOR_H 1

#include <string>

#include "marlin/Processor.h"

namespace EVENT {

	class LCRunHeader;
	class LCEvent;
}

namespace marlintpc {

/** PrimaryCloudIonisationProcessor : This processor takes SimTrackerHits from a simulation (such as Mokka) which contain the position and energy deposits inside the TPC and creates electron clouds from those which can be drifted through the TPC
 * 
 *    @author J. Abernathy (UVic)<br>
 */
class PrimaryCloudIonisationProcessor : public marlin::Processor {

public:
	/**
	 * constructor
	 */
	PrimaryCloudIonisationProcessor();

	/** destructor
	 */
	virtual ~PrimaryCloudIonisationProcessor();

	/** used by Marlin to create a new processor
	 */
	virtual Processor*  newProcessor() { return new PrimaryCloudIonisationProcessor() ; }

	/**
	 * Called at the begin of the job before anything is read.
	 * Use to initialize the processor, e.g. book histograms.
	 */
	virtual void init() ;

	/** Called for every run.
	 */
	virtual void processRunHeader( EVENT::LCRunHeader* run ) ;

	/**
	 * Called for every event - the working horse.
	 */
	virtual void processEvent( EVENT::LCEvent * evt ) ;

	/**
	 * Called after the event has been processed
	 */
	virtual void check( EVENT::LCEvent * evt ) ;

	/**
	 * Called after data processing for clean up.
	 */
	virtual void end() ;

protected:

private:

	/**
	 * the name of the SimTrackerHit input collection from the simulation
	 */
	std::string _input_collection_name;

	/**
	 * the name of the output LCGenericObject collection from this processor containing electron clouds
	 */
	std::string _output_collection_name;

	/** controls if just the energy deposits from the primary particle are considered (true) or all deposits are simulated (false)
	 */
	bool _simulate_only_primary_particle;
};

} // namespace marlintpc

#endif // PRIMARYCLOUDIONISATIONPROCESSOR_H
