
// CLHEP
#include <CLHEP/Vector/ThreeVector.h>

// MarlinTPC
#include "ElectronCloud.h"

using namespace std;
using namespace CLHEP;

namespace marlintpc {

/**
* constructor
*/
ElectronCloud::ElectronCloud() {

	set_x_position(0.);
	set_y_position(0.);
	set_z_position(0.);
	set_time(0.);
	set_electron_count(0);
	set_transverse_stdev(0.);
	set_longitudinal_stdev(0.);
}

/** gets the number of electrons
*/
int ElectronCloud::get_electron_count( void ) const {

	return _obj->getIntVal(0);
}

/** sets the number of electrons
*/
void ElectronCloud::set_electron_count( int count ) {

	_obj->setIntVal(0, count);
}


/** gets the mean x position
*/
double ElectronCloud::get_x_position( void ) const {

	return _obj->getDoubleVal(0);
}

/** sets the mean x position
*/
void ElectronCloud::set_x_position( double x ) {

	_obj->setDoubleVal(0, x);
}


/** gets the mean y position
*/
double ElectronCloud::get_y_position( void ) const {

	return _obj->getDoubleVal(1);
}

/** sets the mean y position
*/
void ElectronCloud::set_y_position( double y ) {

	_obj->setDoubleVal(1, y);
}


/** gets the mean z position
*/
double ElectronCloud::get_z_position( void ) const {

	return _obj->getDoubleVal(2);
}

/** sets the mean z position
*/
void ElectronCloud::set_z_position( double z ) {

	_obj->setDoubleVal(2, z);
}


/** gets the mean time of the cloud
*/
double ElectronCloud::get_time( void ) const {

	return _obj->getDoubleVal(3);
}

/** sets the mean time of the cloud
*/
void ElectronCloud::set_time( double time ) {

	_obj->setDoubleVal(3, time);
}


/** gets the transverse diffusion of the electrons in the cloud
*/
double ElectronCloud::get_transverse_stdev( void ) const {

	return _obj->getDoubleVal(4);
}

/** sets he transverse diffusion of the electrons in the cloud
*/
void ElectronCloud::set_transverse_stdev( double sxy ) {

	_obj->setDoubleVal(4, sxy);
}


/** gets the longitudinal diffusion of the electrons in the cloud
	*/
double ElectronCloud::get_longitudinal_stdev( void ) const {

	return _obj->getDoubleVal(5);
}

/** sets he longitudinal diffusion of the electrons in the cloud
	*/
void ElectronCloud::set_longitudinal_stdev( double sz ) {

	_obj->setDoubleVal(5, sz);
}


/** gets the mean position of the cloud
*/
CLHEP::Hep3Vector ElectronCloud::get_mean_position( void ) const {

	return Hep3Vector( get_x_position(), get_y_position(), get_z_position() );
}

/** sets the mean position of the cloud
*/
void ElectronCloud::set_mean_position( CLHEP::Hep3Vector position ) {

	set_x_position( position.x() );
	set_y_position( position.y() );
	set_z_position( position.z() );
}


/** sets the unique id of this cloud
*/
int ElectronCloud::get_cloud_id( void ) const {

	return _obj->getIntVal(1);
}

/** sets the unique id of this cloud
*/
void ElectronCloud::set_cloud_id( int id ) {

	_obj->setIntVal(1, id);
}


/** returns the typename of the class
*/
const string ElectronCloud::getTypeName( void ) const {

	return string("ElectronCloud");
}


/** returns the type of data in the generic object
*/
const string ElectronCloud::getDataDescription( void ) const {

	return string("i:electron_count,i:id,d:x_position,d:y_position,d:z_position,d:time,d:sxy,d:sz");
}


} // namespace marlintpc
