
// stl
#include <stdio.h>
#include <string>
#include <cstdlib>

// LCIO
#include "lcio.h"
#include "IO/LCWriter.h"
#include "IMPL/LCEventImpl.h"
#include "IMPL/LCCollectionVec.h"

// marlintpc
#include "FieldMapReader.h"



/** A small executable to create an LCIO file holding a field map collection.
 *
 * @author Christian Grefe
 */

void printUsage() {
	std::cout << "Usage:"
			  << "\tFieldMapGenerator input.txt output.slcio [verbosity]" << std::endl
			  << "verbosity is optional, the default is 0" << std::endl
			  << "Text file format:" << std::endl
			  << "\tFieldType <FieldMapType>" << std::endl
			  << "Followed by any number of Int, Float and String parameters:" << std::endl
			  << "\t<type> <parameterName> <value>" << std::endl
			  << "The actual field map starts after:" << std::endl
			  << "\t### Start Field Map ###" << std::endl
			  << "The values depend on the type of the field map." << std::endl
			  << "\tCylindrical2DFieldMap: r[mm] z[mm] Br[T] Bz[T]" << std::endl
			  << "\tCylindrical3DFieldMap: r[mm] phi[rad] z[mm] Br[T] Bphi[T] Bz[T]" << std::endl;
}

int main(int argc, char **argv) {

	if (argc != 3 && argc != 4) {
		printUsage();
		return 1;
	}

	// create an instance of FieldMapReader
	marlintpc::FieldMapReader* reader = marlintpc::FieldMapReader::READER();

	// set verbosity of FieldMapReader
	if (argc == 4) {
		reader->set_verbose(atoi(argv[3]));
	}

	// create the field map collection
	lcio::LCCollection* fieldMap = reader->read_field_map( argv[1] );
	std::string fieldMapName = fieldMap->getParameters().getStringVal("Name");
	if (fieldMapName == "") {
		std::cerr << "The field map has no parameter \"Name\". No LCIO file created" << std::endl;
		return 1;
	}

	// open the output file
	lcio::LCWriter* writer = lcio::LCFactory::getInstance()->createLCWriter();
	writer->open( argv[2], lcio::LCIO::WRITE_NEW );

	// create an event
	lcio::LCEventImpl* event = new lcio::LCEventImpl();

	// add the field map collection to the event
	event->addCollection( fieldMap, fieldMapName );

	// write the event to the lcio file
	writer->writeEvent( event );

	// cleanup
	delete event;
	writer->close();

	return 0;
}
