
// marlintpc
#include "RelativePosition.h"

// lcio
#include "lcio.h"
#include "IMPL/LCCollectionVec.h"
#include "IMPL/LCEventImpl.h"

// stl
#include <cstdlib>

/** A small executable to create an LCIO file holding a coil position to be used with magnetic field maps.
 * In principle this collection should be written automatically to the conditions database instead of creating it by hand.
 *
 * @author Christian Grefe
 */

void printUsage() {
	std::cout << "Usage:" << std::endl
			  << "\tPositionGenerator output.slcio collectionName x_position y_position z_position [x_rotation y_rotation]" << std::endl
			  << "the rotations are optional." << std::endl;
}

int main(int argc, char **argv) {

	if (argc != 6 && argc != 7 && argc != 8) {
		printUsage();
		return 1;
	}

	// read input parameters
	std::string outputFileName = argv[1];
	std::string collectionName = argv[2];
	double xPos = atof(argv[3]);
	double yPos = atof(argv[4]);
	double zPos = atof(argv[5]);
	double xRot = 0.0;
	double yRot = 0.0;
	if (argc > 6) xRot = atof(argv[6]);
	if (argc > 7) yRot = atof(argv[7]);

	// create and fill the position object
	marlintpc::RelativePosition* position = new marlintpc::RelativePosition();
	position->set_x_position( xPos );
	position->set_y_position( yPos );
	position->set_z_position( zPos );
	position->set_x_rotation( xRot );
	position->set_y_rotation( yRot );

	// create an LCCollection and add the position object
	IMPL::LCCollectionVec* positionCol = new IMPL::LCCollectionVec( lcio::LCIO::LCGENERICOBJECT );
	positionCol->addElement( position );

	// create an event and add the collection
	IMPL::LCEventImpl* event = new IMPL::LCEventImpl();
	event->addCollection( positionCol, collectionName );

	// create the output file and write the event
	lcio::LCWriter* writer = lcio::LCFactory::getInstance()->createLCWriter();
	writer->open( outputFileName, lcio::LCIO::WRITE_NEW );
	writer->writeEvent( event );

	// cleanup
	delete event;
	writer->close();

	return 0;
}


