#include "DumpPadCentresProcessor.h"

//C++
#include <iostream>
using namespace std;

//LCIO
#include <IMPL/LCCollectionVec.h>
#include <EVENT/TrackerPulse.h>
//#include <EVENT/TrackerHit.h>

#include <marlin/Global.h>

#include <gearimpl/RectangularPadRowLayout.h>
#include <gearimpl/FixedPadSizeDiskLayout.h>
#include <gear/PadRowLayout2D.h>
#include <gear/TPCParameters.h>

using namespace lcio ;
using namespace marlin ;
using namespace gear;

namespace marlintpc
{

DumpPadCentresProcessor aDumpPadCentresProcessor;
    
DumpPadCentresProcessor::DumpPadCentresProcessor(): Processor("DumpPadCentresProcessor")
{
    // register steering parameters: name, description, class-variable, default value
    registerInputCollection(    LCIO::TRACKERPULSE,
				"InputPulses" , 
				"Name of the input pulses collection"  ,
				_inputColName ,
				std::string("TPCPulses") ) ;
    // modify processor description
    _description = "DumpPadCentresProcessor: Dump coordinates of pads with charge" ;
}
    
void DumpPadCentresProcessor::init() { 

  // usually a good idea to
  printParameters() ;

  // get the pad layout from gear
  try
  {
      _padLayout =  &Global::GEAR->getTPCParameters().getPadLayout() ;
  }
  catch(std::exception& e)
  {
    std::cout << e.what() << std::endl;
    throw e;
  }

//  _nRun = 0 ;
//  _nEvt = 0 ;

}

void DumpPadCentresProcessor::processEvent( LCEvent * evt ) 
{ 
    //read input data
    cout << "Event: " << evt->getEventNumber() << endl;

    // we need a LCCollectionVec to use iterators, as LCCollectios is o not a std::vector
    LCCollectionVec* InputCollection=0;
    try{
	InputCollection = dynamic_cast<LCCollectionVec*>(evt->getCollection( _inputColName )) ;
    }
    catch(DataNotAvailableException &e)
    {
	// no input data
	// just continue ...
	return;
    }


    if( InputCollection != 0 )
    {
//	int trackNr=0;
	cout << "#R/x\t phi/y\t t"<<endl;

	for(LCCollectionVec::iterator it = InputCollection->begin() ; 
	    it < InputCollection->end(); it ++ )
	{
//	    cout <<"\t TrackNumber "<<trackNr++<<endl;
	    TrackerPulse * pulse = dynamic_cast<TrackerPulse *>(*it) ;

	    Vector2D padCentre=_padLayout->getPadCenter(pulse->getCellID0());

	    cout << padCentre[0] << "\t"<< padCentre[1]<< "\t"<<pulse->getTime()<<endl;
        }

    }
}


}// namespace 
